using iFileProxy.Config;
using iFileProxy.Helpers;
using iFileProxy.Middleware;
using iFileProxy.Services;
using Serilog;

namespace iFileProxy
{
    public class Program
    {
        public static void Main(string[] args)
        {
            SerilogConfig.CreateLogger();
            Serilog.ILogger logger = Log.Logger.ForContext<Program>();

            Console.Write(" "); // ǿ֢ſʼ־벻þ

            var builder = WebApplication.CreateBuilder(args);

            //  CORS 
            builder.Services.AddCors(options =>
            {
                options.AddPolicy("AllowFrontend",
                    builder =>
                    {
                        builder
                            .WithOrigins("http://localhost:3000") // ǰ˵ַ
                            .AllowAnyMethod()
                            .AllowAnyHeader()
                            .AllowCredentials();
                    });
            });


            // Add services to the container.

            builder.Services.AddControllers();
            // Learn more about configuring Swagger/OpenAPI at https://aka.ms/aspnetcore/swashbuckle
            builder.Services.AddEndpointsApiExplorer();
            builder.Services.AddSwaggerGen();

            builder.Host.UseSerilog(logger: Log.Logger);

            builder.Services.AddSingleton<Dictionary<string, Dictionary<string, uint>>>(serviceProvider => 
            {
                return new Dictionary<string, Dictionary<string, uint>>();
            });

            builder.Services.AddSingleton(AppConfig.GetCurrConfig());

            builder.Services.AddSingleton<DatabaseGateService>();

            builder.Services.AddSingleton<TaskManager>();

            var app = builder.Build();

            AppConfig.CheckAppConfig(app.Services);

            LocalCacheManager localCacheManager = new(app.Services);

            app.UseSerilogRequestLogging(options =>
            {
                options.EnrichDiagnosticContext = (diagCtx, httpCtx) =>
                {
                    diagCtx.Set("ClientIp", MasterHelper.GetClientIPAddr(httpCtx));
                    diagCtx.Set("contentType", httpCtx.Request.ContentType);
                    diagCtx.Set("queryString", httpCtx.Request.QueryString);
                };
            });

            // Configure the HTTP request pipeline.
            if (app.Environment.IsDevelopment())
            {
                app.UseSwagger();
                app.UseSwaggerUI();
            }

            // м
            app.UseMiddleware<ErrorHandlerMiddleware>();

            app.UseCors("AllowFrontend");

            app.UseHttpsRedirection();

            // Ĭļѡ
            var defaultFilesOptions = new DefaultFilesOptions();
            defaultFilesOptions.DefaultFileNames.Clear(); // Ĭб
            defaultFilesOptions.DefaultFileNames.Add("index.html"); // ԶĬļ

            app.UseDefaultFiles(defaultFilesOptions);

            app.UseStaticFiles();

            app.UseAuthorization();

            app.UseMiddleware<IPAccessLimitMiddleware>(
                app.Services.GetRequiredService<Dictionary<string, Dictionary<string, uint>>>(),
                AppConfig.GetCurrConfig().SecurityOptions.DailyRequestLimitPerIP);

            app.MapControllers();

            app.Run();
        }
    }
}
